@@ -381,9 +381,9 @@ class Contextual(ASN1Object):
     the full DER encoding.  Call choose when the value doesn't have
     the appropriate tag/len info.
     """
-    def __init__(self, tag, len, val):
+    def __init__(self, tag, length, val):
         self.tag = tag
-        self.len = len
+        self.length = length
         self.val = val
         self.unknown = 1
         if self.val:
@@ -392,7 +392,7 @@ class Contextual(ASN1Object):
             self.atomic = 1
     def __repr__(self):
         if self.unknown:
-            return '<contextual %d %d>' % (self.tag, self.len)
+            return '<contextual %d %d>' % (self.tag, self.length)
         elif self.val:
             return "[%d] {" % self.tag + repr(self.val) + "}"
         else:
@@ -408,23 +408,24 @@ class Contextual(ASN1Object):
         if self.unknown:
             p = parse(self.val)
             p.id = 0
-            p.length = self.len
-            self.val = p._parse(tag, self.len)
+            p.length = self.length
+            self.val = p._parse(tag, self.length)
             self.unknown = 0
         return self.val
 
 class Constructed(ASN1Object):
-    def __init__(self, enc, tag, len, val):
+    def __init__(self, enc, tag, length, val):
         self.enc = enc
         self.tag = tag
-        self.len = len
+        self.length = length
         self._parse(val)
 
     def _parse(self, val):
+        assert type(val)==types.StringType,'***bah!'
         p = ASN1Parser(StringIO(val))
         self.val = p.parse()
         self.val_tag = p.tag
-        self.val_len = p.len
+        self.val_length = p.length
 
     def __cmp__(self, other):
 	if isinstance(other, Constructed):
@@ -435,7 +436,7 @@ class Constructed(ASN1Object):
         return "[%d] {%s}" % (self.tag, repr(self.val))
 
     def _encode(self, io):
-        io.write(chr(CONTEXTUAL | CONSTRUCTED | self.tag) + chr(self.len) \
+        io.write(chr(CONTEXTUAL | CONSTRUCTED | self.tag) + chr(self.length) \
                  + encode(self.val))  
 
 
@@ -555,20 +556,18 @@ class ASN1Parser:
     def parse(self):
         try:
             self.tag = tag = self.getTag()
-            self.len = len = self.getLength()
+            self.length = length = self.getLength()
         except EOFError:
             raise ValueError, "unexpected end of encoded data"
-	return self._parse(tag, len)
+	return self._parse(tag, length)
 
-    def _parse(self, tag, len):
+    def _parse(self, tag, length):
         _class = self.id & CLASS_MASK
         if _class == UNIVERSAL:
             try:
                 method = self.__dispatch[tag]
             except KeyError:
                 self.val = self.parseUnknown()
-                print "Decoded unknown value.  tag=%d val=%s" % (tag,
-                                                            repr(self.val)) 
             else:
                 self.val = method(self)
         elif _class == CONTEXTUAL:
@@ -619,7 +618,9 @@ class ASN1Parser:
     def parseSequence(self):
         seq = Sequence()
         base = self.io.tell()
-        newIo = StringIO(self.getBody())
+        body = self.getBody()
+        assert type(body)==types.StringType,'***bah!'
+        newIo = StringIO(body)
         try:
             while 1:
 		obj = ASN1Parser(newIo).parse()
@@ -680,15 +681,15 @@ class ASN1Parser:
         oid = [x, y]
         
         num = None
-        for oct in map(self.ord, buf[1:]):
-            if oct & 0x80:
+        for octet in map(self.ord, buf[1:]):
+            if octet & 0x80:
                 if num:
-                    num = (num << 7L) | (oct & 0x7F)
+                    num = (num << 7L) | (octet & 0x7F)
                 else:
-                    num = long(oct & 0x7f)
+                    num = long(octet & 0x7f)
             else:
                 if num:
-                    final = (num << 7L) | oct
+                    final = (num << 7L) | octet
                     # Is there a better way to do this?
                     # Should I just make it long all the time?
                     try:
@@ -697,7 +698,7 @@ class ASN1Parser:
                         oid.append(final)
                     num = None
                 else:
-                    oid.append(oct)
+                    oid.append(octet)
         return OID(oid)
 
     def parseNull(self):
@@ -841,11 +842,11 @@ def parseCfg(io):
         line = io.readline()
         if line == '':
             break
-        line = string.strip(line)
+        line = line.strip()
         if not line or line[0] == '#':
             continue
         try:
-            name, val = map(string.strip, string.split(line, '=', 1))
+            name, val = map(string.strip,line.split('=',1))
         except ValueError:
             name = line
             val = None
@@ -853,12 +854,11 @@ def parseCfg(io):
         if name == 'OID':
             if oid:
                 oids[oid] = dict
-            bytes = string.join(map(chr,
+            bytes = ''.join(map(chr,
                                     map(eval,
                                         map(lambda s:"0x"+s,
-                                            string.split(val)))), '')
+                                            val.split(' ')))))
             oid = parse(bytes)
-            key = oid
             dict = {}
         else:
             dict[name] = val
@@ -867,6 +867,7 @@ def parseCfg(io):
     return oids
 
 def parse(buf):
+    assert type(buf)==types.StringType,'***bah!'
     return ASN1Parser(StringIO(buf)).parse()
 
 
