@@ -1,20 +1,20 @@
 """
 utctime.py - various functions for parsing display UTCTime
-
 (c) by Michael Stroeder <michael@stroeder.com>
 
 This module is distributed under the terms of the
 GPL (GNU GENERAL PUBLIC LICENSE) Version 2
 (see http://www.gnu.org/copyleft/gpl.html)
-"""
 
-import time
+$Id: utctime.py,v 1.5 2001/11/23 12:41:50 michael Exp $
+"""
 
 def strptime(s):
   """
   Parse a UTC time string.
   """
-  if len(s)==15:
+  s = s.split('.')[0]
+  if len(s)>=14:
     # YYYYmmddHHMMSS
     year,month,day,hour,minute,second = int(s[0:4]),int(s[4:6]),int(s[6:8]),int(s[8:10]),int(s[10:12]),int(s[12:14])
   else:
@@ -32,4 +32,7 @@ def strptime(s):
 
 
 def strftimeiso8601(t):
-  return time.strftime('%Y-%m-%dT%H:%M:%SZ',t)
+  year,month,day,hour,minute,second,dummy,dummy,dummy = t
+  return '%04d-%02d-%02dT%02d:%02d:%02dZ' % (
+    t[0],t[1],t[2],t[3],t[4],t[5]
+  )
